from setuptools import setup, find_packages

setup(
    name='pythonMY',
    version='0.1',
    description='Packet de biblio scapy pour analyser le reseau',
    author='MOHAMED HAOUARI',
    author_email='mohamed.haouari.2001@gmail.com',
    packages=find_packages(),
)




